@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2008-2015 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2008-2017 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -66,11 +66,19 @@ void Cmeterdsp::process (float *pl, float *pr, int n)
 	zll += _w2 * (zl * zl - zll);
 	zrr += _w2 * (zr * zr - zrr);
     }
-    _zl = zl;
-    _zr = zr;
-    _zlr = zlr;
-    _zll = zll;
-    _zrr = zrr;
+    if (    isnormal (zl)
+	 && isnormal (zr)
+	 && isnormal (zlr)
+	 && isnormal (zll)
+	 && isnormal (zrr))
+    {
+        _zl = zl;
+        _zr = zr;
+        _zlr = zlr;
+        _zll = zll;
+        _zrr = zrr;
+    }
+    else reset ();
 }
 
 
