@@ -43,7 +43,7 @@ Mainwin::Mainwin (X_rootwin *parent, X_resman *xres, Jclient *jclient) :
     XSetWMProtocols (dpy (), win (), &_atom, 1);
     _atom = XInternAtom (dpy (), "WM_PROTOCOLS", True);
 
-    sprintf (s, "%s - %s  [ %s ]", PROGRAM, VERSION, jclient->jname ());
+    sprintf (s, "%s-%s  [ %s ]", "zita-mu1", VERSION, jclient->jname ());
     x_set_title (s);
 
     xp = 100;
@@ -324,12 +324,12 @@ void Mainwin::disp_monmod (void)
     for (i = 0; i < 3; i++)
     {
 	B = _buttons [B_LEFT + i];
-	if (i + 1 == m) B->set_state (2);
-	else            B->set_state (0);
+	if (i + 1 == m) B->set_state (B->state () | 2);
+	else            B->set_state (B->state () & ~2);
     }
     B = _buttons [B_DIMM];
-    if (_monmod & 16) B->set_state (2);
-    else              B->set_state (0);
+    if (_monmod & 16) B->set_state (B->state () | 2);
+    else              B->set_state (B->state () & ~2);
 }
 
 
@@ -341,12 +341,12 @@ void Mainwin::disp_outsel (void)
     for (i = 0, m = _outsel; i < 2; i++, m >>= 1)
     {
 	B = _buttons [B_OUT1 + i];
-	if (m & 1) B->set_state (2);
-	else       B->set_state (0);
+	if (m & 1) B->set_state (B->state () | 2);
+	else       B->set_state (B->state () & ~2);
     }
     B = _buttons [B_HDPH];
-    if (_outsel & 16) B->set_state (2);
-    else              B->set_state (0);
+    if (_outsel & 16) B->set_state (B->state () | 2);
+    else              B->set_state (B->state () & ~2);
 }
 
 
@@ -382,7 +382,7 @@ void Mainwin::makegui (void)
     _buttons [B_INP3] = new Pbutt1 (this, this, B_INP3, I, x + 60, y, 26, 26);
     I = loadpng ("binp4");
     _buttons [B_INP4] = new Pbutt1 (this, this, B_INP4, I, x + 90, y, 26, 26);
-    addtext (this, &Tst0, x + 10, y + 25, 100, 20, "Input", 0);
+    addtext (this, &Tst0, x + 10, y + 26, 100, 20, "Input", 0);
     _inpsel = 1;
     _buttons [B_INP1]->set_state (2);
 
@@ -468,7 +468,7 @@ void Mainwin::makegui (void)
     _rtblev2->x_map ();
     _jclient->set_tb2gain (_rtblev2->value ());
 
-    _dispwin = new X_subwin (this, 330, 2, DISP_XS, DISP_YS, Colors [C_DISP_BG]); 
+    _dispwin = new X_subwin (this, 330, 2, DISP_XS, DISP_YS, XftColors [C_DISP_BG]->pixel); 
     _dispwin->x_add_events (ExposureMask);
     _dispwin->x_map ();
 
@@ -518,11 +518,11 @@ void Mainwin::redraw_disp (void)
     X_draw   D (dpy (), _dispwin->win (), dgc (), 0);
     XImage   *I;
 
-    D.setcolor (Colors [C_MAIN_DS]);
+    D.setcolor (XftColors [C_MAIN_DS]->pixel);
     D.move (0, DISP_YS - 1);
     D.draw (0, 0);
     D.draw (DISP_XS - 1, 0);
-    D.setcolor (Colors [C_MAIN_LS]);
+    D.setcolor (XftColors [C_MAIN_LS]->pixel);
     D.move (1, DISP_YS - 1);
     D.draw (DISP_XS - 1, DISP_YS - 1);
     D.draw (DISP_XS - 1, 1);
