@@ -46,8 +46,8 @@ static Mainwin  *mainwin = 0;
 
 static void help (void)
 {
-    fprintf (stderr, "\n%s-%s\n\n", PROGRAM, VERSION);
-    fprintf (stderr, "  (C) 2012 Fons Adriaensen  <fons@linuxaudio.org>\n\n");
+    fprintf (stderr, "\nzita-mu1-%s\n\n", VERSION);
+    fprintf (stderr, "  (C) 2012-2015 Fons Adriaensen  <fons@linuxaudio.org>\n\n");
     fprintf (stderr, "Options:\n");
     fprintf (stderr, "  -h              Display this text\n");
     fprintf (stderr, "  -name <name>    Jack client name\n");
@@ -72,7 +72,7 @@ int main (int ac, char *av [])
     X_rootwin     *rootwin;
     int            ev;
 
-    xresman.init (&ac, av, CP PROGRAM, options, NOPTS);
+    xresman.init (&ac, av, CP"zita-mu1", options, NOPTS);
     if (xresman.getb (".help", 0)) help ();
             
     display = new X_display (xresman.get (".display", 0));
